@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,12 +24,10 @@
 #include <QDialog>
 #include <AkonadiCore/Tag>
 #include <AkonadiCore/TagCreateJob>
-#include <KConfigGroup>
 
 class KActionCollection;
 
-namespace MailCommon
-{
+namespace MailCommon {
 class AddTagDialogPrivate;
 class MAILCOMMON_EXPORT AddTagDialog : public QDialog
 {
@@ -38,8 +37,8 @@ public:
     ~AddTagDialog();
 
     void setTags(const QList<MailCommon::Tag::Ptr> &tags);
-    QString label() const;
-    Akonadi::Tag tag() const;
+    Q_REQUIRED_RESULT QString label() const;
+    Q_REQUIRED_RESULT Akonadi::Tag tag() const;
 
 private:
     void slotSave();
